This script joins multiple audio files into one.

Install:
```shell
pipx install joinvoice
```

And make one nice package of all the dear voice messages:
```shell
joinvoice path_to_folder_with_sources output_filename.ogg
```
